{% load staticfiles %}
{% load wagtailcore_tags wagtailimages_tags wagtailsettings_tags %}
{% get_settings %}

<footer class="footer">
    <div class="container pt-5">
        <div class="row">
            {% with footer=settings.ocyan_plugin_wagtail.OcyanSettings.footer %}
            {% for block in footer %}
            <div class="{% if block.block_type == 'SubscriptionBlock' %}col-lg-6{% else %}col-lg-3{% endif %} col-md-6 col-sm-12 footer_column">
                {% include_block block %}
            </div>
            {% endfor %}
            {% endwith %}
        </div>
        <div class="container pt-5">
            <hr class="mb-5">
            <div class="row">
                <div class="col-lg-12 copyright_block">
                    {% include_block settings.ocyan_plugin_wagtail.OcyanSettings.mini_footer %}
                </div>
            </div>
        </div>
    </div>
</footer>