{% load ocyan_thumbnail wagtailcore_tags styling_tags %}
<section class="hero image-hero parallax">
		{% if self.ornaments.overlay %}
		<div class="image-wrapper has-overlay">
		<span class="overlay"></span>
		{% else %}
		<div class="image-wrapper">
		{% endif %}

		{% responsive_image self.image.file alt=self.image.title classes="background-image parallax-image" %}
		{% if self.ornaments.wave %}
			{% include "svg/hero_waves_element.svg" %}
		{% endif %}
	</div>
	<div class="container{% if self.ornaments.center_text %} text-center{% endif %}">
		<div class="hero-lead">
			{{ self.body|richtext }}
		</div>
		{% if self.buttons %}
		<div class="buttons-wrapper d-flex gap-3">
			{% for button in self.buttons %}
				{% include "coyote/blocks/partials/button.html" %}
			{% endfor %}
		</div>
		{% endif %}
	</div>
</section>
