{% extends "carbasa/headers/header.html" %}
{% load i18n oxyan category_tags ocyan_main ocyanjson %}

{% block nav %}
{% ocyanjson "theme" "menu_depth" 1 as menu_depth %}
<div class="collapse navbar-collapse menu-bar page-menu-bar" id="navbarSupportedContent">
    <div class="brand-wrapper">
        {% include 'partials/brand.html' with big=True %}
    </div>
    <ul class="navbar-nav">
        {% rootpage_as_category as page_tree_root %}
        {% category_tree 2 page_tree_root as page_tree_items %}
        {% include "partials/dropdown.html" with menu_items=page_tree_items limit=2 %}
    </ul>
</div>
{% endblock %}