{% load wagtailcore_tags ocyan_thumbnail %}
<section class="centertext {{self.coyote_bg}}" id="{{ self.coyote_anchor }}">
	{% include "svg/hero_waves_element.svg" %}
	<div class="container">
		<div class="row">
			<div class="col-lg-8 mx-auto text-xl-center">
				{{ self.body|richtext }}
			</div>
			<div class="col-lg-12">
				{% if self.buttons %}
				<div class="buttons-wrapper justify-content-center mb-5">
					{% for button in self.buttons %}
						{% include "coyote/blocks/partials/button.html" with button=button %}
					{% endfor %}
				</div>
				{% endif %}
				<div class="d-flex justify-content-center align-items-center">
					{% lazy_responsive_image self.image.file classes="img-fluid" %}
				</div>
			</div>
		</div>
	</div>
</section>