{% extends "layout.html" %}

{% load oxyan static i18n %}

{% block navbar %}
    {% include_header "carbasa/headers/header.html" %}
{% endblock %}

{% block footer %}
    {% if not self.footer %}
        <div class="footer-corners">
            {% include "svg/corner.svg" with class="left" %}
            {% include "svg/corner.svg" with class="right" %}
        </div>
    {% endif %}
    {% include "oxyan/partials/footer.html" %}
{% endblock %}

{% block extrascripts %}
    {{block.super}}
    <script type="text/javascript" src="{% static 'carbasa/js/carbasa.js' %}"></script>
{% endblock %}

{% block onbodyload %}
    {{ block.super }}
    oxyan.initSliders(".quotes_wrapper", {loop: false, nav: false, controls: true, autoplay:false, autoHeight:false, items:1})
    oxyan.initParallax();
{% endblock %}


{% block layout %}
    <a class="btn btn-secondary hidelink" id="main_content_link" href="#skip_header" tabindex="2">
        {% trans "Ga naar inhoud" %}
    </a>

    {{block.super}}
{% endblock %}
