{% extends "layout.html" %}

{% block onbodyload %}
    {{ block.super }}
    oxyan.initSliders(".iconslider", {autoHeight:true, controls:false, nav:false, center:true, autoplay:true, loop:true, slideBy:1, autoplayTimeout:2000, autoplayButtonOutput:false, responsive: {0: {items: 2,}, 991: {items: 6,}}})
    oxyan.initSliders(".products-slider-wrapper", {lazy:true, gutter:30, controls:true, nav:false, autoplay:false, loop:false, slideBy:1,
    autoplayTimeout:2000, autoplayButtonOutput:false, responsive: {0: {items: 2, controls:true}, 991: {items: 4, controls:true}}})
    oxyan.initSliders(".category-slider-wrapper", {loop: false, nav: false, controls: true, autoplay:false, autoHeight:false, gutter: 30, slideBy:1, responsive: {0: {items: 1.25, controls:true}, 991: {items: 4, controls:true}}})
{% endblock %}
