{% load i18n oxyan category_tags ocyan_main ocyanjson %}

<header>
    <nav class="navbar navbar-expand-lg navbar-light header-inner">
        <div class="container">
            {% include 'partials/brand.html' with big=True %}

            {% block nav %}
            {% ocyanjson "theme" "menu_depth" 1 as menu_depth %}
            <div class="collapse navbar-collapse menu-bar page-menu-bar" id="navbarSupportedContent">
                <div class="brand-wrapper">
                    {% include 'partials/brand.html' with big=True %}
                </div>
                <ul class="navbar-nav">
                    {% rootpage_as_category as page_tree_root %}
                    {% category_tree 2 page_tree_root as page_tree_items %}
                    {% include "partials/dropdown.html" with menu_items=page_tree_items limit=2 %}
                </ul>
            </div>
            {% endblock %}
            {% block append_header_block %}{% endblock %}
            <button type="button" class="btn btn-link p-0 border-0 bg-transparent search-toggler" aria-label="{% trans 'Open search' %}">
                {% trans "zoeken" %}
            </button>
            <button class="navbar-toggler collapsed" aria-label="Navbar toggle" type="button" data-bs-toggle="collapse" data-bs-target="#navbarSupportedContent">
                <i class="fa fa-bars nav-icon"></i>
                <i class="fa fa-times nav-icon"></i>
            </button>
        </div>
    </nav>
</header>
