{% load wagtailcore_tags %}
<section class="products-block {{ self.layout }} {{self.coyote_bg}}" id="{{ self.coyote_anchor }}">
	<div class="container">
		{% if self.header %}
		<div class="row">
			<div class="col-lg-6 text-start">
				{% if self.tagline %}<span class="badge bg-primary mb-2">{{ self.tagline }}</span>{% endif %}
				<h2 class="mb-0">{{self.header}}</h2>
			</div>
			<div class="col-lg-6 d-flex">
				{% if self.buttons %}
				<div class="buttons-wrapper justify-content-lg-end d-flex mt-lg-auto mt-3 ms-lg-auto">
					{% for button in self.buttons %}
						{% include "coyote/blocks/partials/button.html" with button=button %}
					{% endfor %}
				</div>
				{% endif %}
			</div>
		</div>
		<hr>
		{% endif %}
		<div class="products-slider-wrapper">
		{% for product in self.products %}
			<div class="product-outer">
				{% include "oscar/catalogue/partials/product.html" %}
			</div>
		{% endfor %}
		</div>
	</div>
</section>