.product-detail{
	@include media-breakpoint-up(lg){
		padding-top: 3rem;
		padding-bottom: 3rem;
	}
	@include media-breakpoint-down(lg){
		padding-top: 1rem;
		padding-bottom: 1rem;
	}
	.add-to-basket-form{
		display: flex;
		flex-direction: column;
		gap: 1rem;
	}
	.recently-viewed-products{
		.product{
			display: flex;
			flex-direction: column;
			.product-info{
				margin-top: auto;
			}
		}
	}
	.from_price{
		text-decoration: line-through;
	}
	.right-side{
		height: 100%;
		position: sticky;
		top: 2rem;
		.right-side-inner{
			padding: 2rem;
			background: $light;
			border-radius: $border-radius-lg;
		}
		& > div > div{
			&:not(:first-child){
				margin-top: 1rem;
			}
			margin-bottom: 1rem;
		}
		.breadcrumb-wrapper{
			@include media-breakpoint-up(lg){
				margin-bottom: -.5rem;
			}
			padding-top: 0;
			padding-bottom: 0;
			font-size: .8rem;
			a{
				color: color-contrast($body-bg);
				text-decoration: unset;
			}
		}
		.accordion{
			.accordion-item{
				border: 0;
				background: transparent;
				.accordion-header{
					button{
						padding: 1rem 0;
						background: transparent !important;
						box-shadow: unset !important;
						font-weight: $headings-font-weight;
						font-weight: 600;
						&:before{
							content: "\f03a";
							font-family: Highbiza, sans-serif;
							background: unset;
							position: absolute;
							top: 1rem;
							right: 0;
							transition: .4s $easing;
						}
						&:after{
							display: none;
						}
						&:not(.collapsed){
							color: $body-color;
							&:before{
								content: "\f039";
								transform: rotate(180deg);
							}
						}
					}
				}
				.accordion-body{
					padding: 0;
				}
				table{
					th{
						font-weight: 600;
						padding-left: 0;
					}
				}
			}
		}
		.product-rating{
			display: flex;
			gap: .5rem;
			flex-wrap: wrap;
			margin-bottom: 0 !important;
			i:not(.half){
				font-size: .75rem;
				margin-right: 0rem;
				color: #f59e0a;
			}
			.fa-star-solid.half:after{
				color: #f59e0a;
			}
		}
		.stock-record{
			.stock_price{
				font-size: 1.5rem;
				@include media-breakpoint-down(lg){
					margin-top: .5rem;
					display: flex;
					flex-wrap: wrap;
					flex-direction: column-reverse;
					font-size: 1rem;
				}
				.first-session-price{
					font-weight: 600;
					color: $price-color;
					margin-right: .5rem;
				}
				.second-session-price{
					opacity: .65;
					font-size: 70%;
				}
			}
		}
	}
}

.basket-button-wrapper{
	display: flex;
	gap: 1rem;
	justify-content: flex-start;
	.basket-inline{
		display: flex;
		width: 100%;
		max-width: 300px;
		& > label{
			max-width: 100px;
		}
		button{
			width: 100%;
		}
	}
}

.no-caret{
	&:after{
		display: none;
	}
}

.carbasa-gallery-2{
	@include media-breakpoint-up(lg){
		display: flex;
		flex-direction: column;
		gap: 2rem;
	}
}

.carbasa-gallery-1{
	display: flex;
	flex-wrap: wrap;
	border-radius: $border-radius;
	overflow: hidden;
	position: relative;
	.counter{
		position: absolute;
		bottom: 1rem;
		right: 1rem;
		background: var(--bs-light);
		display: flex;
		justify-content: center;
		align-items: center;
		width: 40px;
		height: 40px;
		border-radius: $border-radius;
		pointer-events: none;
		font-weight: 600;
	}
	.invisible{
		display: none;
	}
	& > div{
		width: 50%;
		flex-grow: 1;
		a{
			width: 100%;
			height: 100%;
			overflow: hidden;
			display: block;
			&:hover{
				img{
					transform: scale(1.1);
				}
			}
			img{
				height: 300px;
				object-fit: cover;
				width: 100%;
				transition: 1s $easing;
				@include media-breakpoint-down(lg){
					height: 175px;
				}
			}
		}
	}
}

[for="#id_quantity"]{
	.form-group{
		display: none;
	}
}

.add-to-basket-wrapper{
	display: flex;
	flex-direction: column;
	gap: 1rem;
	.alert{
		margin-bottom: 0;
		padding: .5rem;
		display: inline-block;
		margin-right: auto;
	}
}

.mfp-gallery{
	backdrop-filter: blur(8px);
	animation: fadeIn .3s $easing;
	.mfp-arrow-right, .mfp-arrow-left{
		display: flex;
		justify-content: center;
		align-items: center;
		&:before, &:after{
			margin: 0 !important;
			position: unset;
			border: 0;
			font-family: "Highbiza";
			color: white;
			font-size: 3rem;
			width: auto;
			height: auto;
		}
	}
	.mfp-arrow-right:before{
		content: "\f092";
	}
	.mfp-arrow-left:before{
		content: "\f04c";
	}
	.mfp-figure{
		&:after{
			display: none;
		}
		.mfp-img{
			animation: LoadImage .3s $easing;
		}
	}
}
.mfp-bg.mfp-ready{
	animation: fadeInBackground .75s $easing;
}

@keyframes LoadImage{
	from{ transform: translateY(-20px); opacity: 0; }
	to{ transform: translateY(0px); opacity: 1; }
}

@keyframes fadeInBackground{
	from { opacity: 0; }
	to { opacity: .8; }
}
@keyframes fadeIn{
	from { opacity: 0; }
	to { opacity: 1; }
}