{% if button.label %}
<a class="btn btn-{{ button.button_style }}" href="{{button.link.get_url}}" {% if button.new_tab %}target="_blank"{% endif %}>
	<small><span><span>{{ button.label }}</span><span class="d-none">{{ button.label }}</span></span> <i class="d-none fa fa-arrow-right"></i></small>
</a>
{% endif %}