{% load wagtailcore_tags %}

<section class="carbasa_cta_footer">
	<div class="container">
		<div class="container-inner px-lg-0 px-3">
			<div class="row py-5">
				<div class="col-lg-8 pe-lg-5">
					<h2>{{self.header}}</h2>
				</div>
				<div class="col-lg-4 my-auto ps-lg-5">
					<div>{{ self.body|richtext }}</div>
					{% if self.button %}
					<div class="buttons-wrapper justify-content-end">
						{% include "coyote/blocks/partials/button.html" with button=self.button %}
					</div>
					{% endif %}
				</div>
			</div>
		</div>
	</div>
</section>