{% extends "base.html" %}

{% load static %}

{% block base_css %}
    {% comment %}
        We do NOT call super in this block because we override the oxyan base themes,
        as we do not want to load this.
    {% endcomment %}
    <link rel="stylesheet" type="text/x-scss" href="{% static 'carbasa/coyote_base.scss' %}">
{% endblock %}
