{% extends "layout.html" %}

{% block content_wrapper %}
	<div class="container my-5 pb-5">
		<div class="row">
			<div class="col-lg-7">
				<div class="bg-light p-lg-5 p-4">
					{{block.super}}
				</div>
			</div>
		</div>
	</div>
{% endblock %}