{% extends "carbasa/headers/header.html" %}
{% load i18n oxyan category_tags ocyan_main ocyanjson wagtailsettings_tags %}

{% block nav %}
{% ocyanjson "theme" "menu_depth" 1 as menu_depth %}
<div class="collapse navbar-collapse menu-bar page-menu-bar" id="navbarSupportedContent">
    <div class="brand-wrapper">
        {% include 'partials/brand.html' with big=True %}
    </div>
    <ul class="navbar-nav">
		<li class="megamenu nav-item">
            <span class="overlay"></span>
			<a class="toggler nav-link" tabindex="0" aria-label="Open Megamenu">
				{% trans "Our Collection" %} <i class="fa fa-chevron-down small ms-1"></i>
			</a>
            <div class="outer">
                <nav id="header_breadcrumb" aria-label="breadcrumb">
                    <ol class="breadcrumb">
                        <li class="breadcrumb-item"><a data-path="root" tabindex="-1">{% trans "Our collection" %}</a></li>
                    </ol>
                </nav>
    			<ul class="inner">
                    <li class="category-main">
                        <a class="nav-link main-assortment" data-name="{{ menu_item.name|safe }}" href="{% url 'catalogue:index' %}" tabindex="-1">
                            {% trans "View" %} <b class="ms-1">{% trans "Our Collections" %}</b>
                        </a>
                    </li>
            		{% category_tree depth=menu_depth as category_tree_items %}
                	{% include "webshop/mega_dropdown.html" with menu_items=category_tree_items %}
            	</ul>
            </div>
    	</li>
        {% rootpage_as_category as page_tree_root %}
        {% category_tree 2 page_tree_root as page_tree_items %}
        {% include "partials/dropdown.html" with menu_items=page_tree_items limit=2 %}
    </ul>
</div>
{% endblock %}