@import "coyote/mixins";

.coyote-outer{
	&:not(.monochrome){
		.coyote-wrapper{
			& > div{
				&:nth-child(3n-2) > section{
					@include section_white;
				}
				&:nth-child(3n-1) > section, & > section.dark{
					@include section_dark;
				}
				&:nth-child(3n) > section, & > section.light{
					@include section_light;
				}
				// Repeated for overwrite
				& > section.background_body{
					@include section_white;
				}
				& > section.dark{
					@include section_dark;
				}
				& > section.light{
					@include section_light;
				}
			}
		}
	}
	&.monochrome{
		section{
			--icon-block-background: #{$primary};
			--icon-block-color: #{color-contrast($primary)};
			--icon-block-background-hover: #{lighten($primary, 10%)};
			--icon-block-color-hover: #{color-contrast(lighten($primary, 10%))};
			--counter-color: #{color-contrast($gray-200)};
			--background: #{$gray-200};
			--contrast-color: #{darken($dark, 5%)};
		}
	}
	.coyote-wrapper{
		& > div{
			.coyote-block-wrapper, .image_with_text, .icons_with_text, .iconslider-wrapper{
				padding-top: 0;
				padding-bottom: 0;
			}
			@include media-breakpoint-down(xl){
				$cy-spacer: $cy-spacer / 2;
			}
			&:nth-child(3n-2) > section, & > section.background_body{
				margin-top: $cy-spacer;
				margin-bottom: $cy-spacer;
				padding-top: 0 !important;
				padding-bottom: 0 !important;
				@include media-breakpoint-down(xl){
					margin-top: $cy-spacer / 2;
					margin-bottom: $cy-spacer / 2;
				}
			}
			&:nth-child(3n) > section, & > section.light,
			&:nth-child(3n-1) > section, & > section.dark{
				padding-top: $cy-spacer;
				padding-bottom: $cy-spacer;
				@include media-breakpoint-down(xl){
					padding-top: $cy-spacer / 2;
					padding-bottom: $cy-spacer / 2;
				}
			}
		}
	}
}