{% load ocyan_thumbnail %}

<div class="banner-block">
	<div class="container">
		<div class="row mx-0">
			<div class="col-lg-6 px-0">
				<a class="banner" href="{{ self.b1_link }}" title="Link to the page {{ self.b1_link }}">
					{% responsive_image self.b1_image.file classes="background-image" %}
					<div class="banner-info">
						<p class="mb-0">{{ self.b1_tagline }}</p>
						<h4 class="my-3">{{ self.b1_header }}</h4>
						<span class="d-inline-flex gap-3 align-items-center"><small>{{ self.b1_cta }}<i class="fa fa-arrow-right ms-2"></i></small></span>
					</div>
				</a>
			</div>
			<div class="col-lg-6 px-0">
				<a class="banner" href="{{ self.b2_link }}" title="Link to the page {{ self.b2_link }}">
					{% responsive_image self.b2_image.file classes="background-image" %}
					<div class="banner-info">
						<p class="mb-0">{{ self.b2_tagline }}</p>
						<h4 class="my-3">{{ self.b2_header }}</h4>
						<span class="d-inline-flex gap-3 align-items-center"><small>{{ self.b2_cta }}<i class="fa fa-arrow-right ms-2"></i></small></span>
					</div>
				</a>
			</div>
		</div>
	</div>
</div>