@mixin css-slider($size, $buffer){
    display: flex;
    flex-wrap: nowrap;
    overflow: scroll;
    flex-direction: row;
    scroll-snap-type: x mandatory;
    -ms-overflow-style: none;
    scrollbar-width: none;
    transition: .3s ease;
    &.flex-column{
        flex-direction: row;
    }
    &::-webkit-scrollbar {
        display: none;
    }
    & > *{
        &:first-child{
            min-width: calc(#{$size} + #{$buffer});
            width: calc(#{$size} + #{$buffer});
        }
        min-width: #{$size};
        width: #{$size} !important;
        scroll-snap-align: center;
        padding-right: #{$buffer};
        h4, h3{
            font-size: 1.7rem;
        }
        .icon-block{
            padding: 1.5rem;
        }
    }
}