{% extends "coyote/coyote_page.html" %}
{% load wagtailcore_tags static %}

{% block content %}
	<div class="coyote">
		{% include_block self.header %}
		<div class="coyote-wrapper{% if self.footer %} footer_colored{% endif %}">
			{% include_block self.content %}
		</div>
		<div class="footer-corners">
			{% include "svg/corner.svg" with class="left" %}
			{% include "svg/corner.svg" with class="right" %}
		</div>
		{% include_block self.footer %}
	</div>
{% endblock %}