{% load ocyan_thumbnail wagtailcore_tags styling_tags roadrunner_tags %}
<section class="accordion-block-wrapper {{self.coyote_bg}}" id="{{ self.coyote_anchor }}">
    <div class="container">
        <div class="row">
            <div class="col-lg-8 text-center mx-auto">
            	<div>
            		<h3>{{ self.header }}</h3>
                	<p class="mb-0">{{ self.body }}</p>
            	</div>
                {% get_unique_id as accordion_id %}
                <div class="accordion" id="accordion{{ accordion_id }}">
                    {% for accordion in self.accordion %}
                        {% get_unique_id as accordion_item_id %}
                        <div class="accordion-item">
                            <h4 class="accordion-header" id="headingOne{{ accordion_item_id }}">
                                <button class="accordion-button collapsed px-0 py-3 shadow-none" type="button" data-bs-toggle="collapse" data-bs-target="#accordion_item_{{ accordion_item_id }}" aria-expanded="false" aria-controls="accordion_item_{{ accordion_item_id }}">
                                    <span>{{ accordion.header }}</span>
                                    <i class="fa fa-plus ms-3 small" aria-hidden="true"></i>
                                </button>
                            </h4>
                            <div id="accordion_item_{{ accordion_item_id }}" class="accordion-collapse collapse" aria-labelledby="headingOne{{ accordion_item_id }}" data-bs-parent="#accordion{{ accordion_id }}">
                                <div class="accordion-body text-start small px-0">
                                    {{ accordion.body }}
                                </div>
                            </div>
                        </div>
                    {% endfor %}
                </div>
            </div>
        </div>
    </div>
</section>
