{% extends "base.html" %}

{% load static %}

{% block base_css %}
    {% comment %}
        We DO call super in this block, because this one inherits from the
        ocyan.plugin.carbase.templates.layout.html template, and this one already does
        not load oxyan themes base scss.
    {% endcomment %}
    {{ block.super }}
    <link rel="stylesheet" type="text/x-scss" href="{% static 'carbasa/webshop_base.scss' %}">
{% endblock %}
