{% load wagtailcore_tags ocyan_thumbnail i18n %}
{% trans "Website logo" as default_logo_alt %}

<div class="pe-lg-5">
	{% if settings.ocyan_plugin_wagtail.OcyanSettings.logo %}
		{% picture settings.ocyan_plugin_wagtail.OcyanSettings.logo.file "300x300" classes="img-fluid mb-3 aboutus-logo" alt=settings.ocyan_plugin_wagtail.OcyanSettings.logo_alt|default:default_logo_alt %}
	{% endif %}
	{% include_block self.bound_blocks.content %}

	{% with settings=settings.ocyan_plugin_wagtail.OcyanSettings %}
	<div class="social">
	    {% if settings.facebook_url %}
	    <a aria-label="Facebook link" href="{{ settings.facebook_url }}"><i class="fa fa-facebook" aria-hidden="true" role="button"></i></a>
	    {% endif %}
	    {% if settings.twitter_url %}
	    <a aria-label="Twitter link" href="{{ settings.twitter_url }}"><i class="fa fa-twitter-x" aria-hidden="true" role="button"></i></a>
	    {% endif %}
	    {% if settings.linkedin_url %}
	    <a aria-label="Linkedin link" href="{{ settings.linkedin_url }}"><i class="fa fa-linkedin" aria-hidden="true" role="button"></i></a>
	    {% endif %}
	    {% if settings.instagram_url %}
	    <a aria-label="Instagram link" href="{{ settings.instagram_url }}"><i class="fa fa-instagram" aria-hidden="true" role="button"></i></a>
	    {% endif %}
	    {% if settings.youtube_url %}
	    <a aria-label="Youtube link" href="{{ settings.youtube_url }}"><i class="fa fa-youtube" aria-hidden="true" role="button"></i></a>
	    {% endif %}
	    {% if settings.pinterest_url %}
	    <a aria-label="Pinterest link" href="{{ settings.pinterest_url }}"><i class="fa fa-pinterest" aria-hidden="true" role="button"></i></a>
	    {% endif %}
		{% if settings.tiktok_url %}
			<a aria-label="Tiktok link" href="{{ settings.tiktok_url }}"><i class="fa fa-tiktok" aria-hidden="true" role="button"></i></a>
	    {% endif %}
	</div>
	{% endwith %}
</div>
