# -*- coding: utf-8 -*-
from setuptools import find_packages, setup

install_requires: list = ["ocyan.core", "ocyan.plugin.coyote", "oxyan.themes"]

extras_require: dict = {
    "test": [
        "empty_testproject",
        "ocyan.plugin.testing",
        "pylint-django",
        "ruff",
        "vdt.versionplugin.wheel",
        "coverage",
        "ocyan.plugin.wagtail_oscar_integration",
    ]
}

PACKAGE_CLASSIFIERS = [
    "License :: Other/Proprietary License",
    "Framework :: Ocyan",
    "Environment :: Plugins",
]

setup(
    name="ocyan.plugin.carbasa",
    version="0.1.3",
    url="https://git.mandelblog.com/mandel-plugins/ocyan.plugin.carbasa",
    author="Mandel",
    author_email="info@mandelblog.com",
    description=(
        "An extension of coyote plugin to easily update styling of webshop,"
        " by updating settings in wagtail admin."
    ),
    packages=find_packages(),
    include_package_data=True,
    python_requires=">=3.6",
    install_requires=install_requires,
    classifiers=PACKAGE_CLASSIFIERS,
    extras_require=extras_require,
)
