{% load ocyan_thumbnail wagtailcore_tags styling_tags wagtailembeds_tags %}
<section class="hero full-screen video {{ self.layout }}{% if self.overlay %} has-overlay{% endif %}">
	{{self.auto_play|safe}}
	{% include "svg/hero_waves_element.svg" %}
	{% if self.overlay %}
	<span class="overlay"></span>
	{% endif %}
	<div class="container{% if self.center_text %} text-center{% endif %}">
		<div class="hero-lead">
			{{ self.body|richtext }}
		</div>
		{% if self.buttons %}
		<div class="buttons-wrapper d-flex gap-3">
			{% for button in self.buttons %}
				{% include "coyote/blocks/partials/button.html" %}
			{% endfor %}
		</div>
		{% endif %}
	</div>
</section>
<div id="down" class="d-flex justify-content-center">
	<a class="hero-go-down" href="#down"><i class="fa fa-long-arrow-right"></i></a>
</div>
