# -*- coding: utf-8 -*-
default_app_config = "ocyan.plugin.carbasa.apps.OcyanPluginCarbasaAppConfig"

__all__ = ["CarbasaConfig"]


def __getattr__(name):
    if name == "CarbasaConfig":
        from .entrypoint import CarbasaConfig

        return CarbasaConfig
    raise AttributeError(f"module {__name__!r} has no attribute {name!r}")
