{% load i18n %}
			<div class="header-right">
                <a tabindex="0" aria-label="Open Search" role="search" class="search-toggler user-button menu-circle">
                    <i class="fa fa-search"></i>
                </a>
                <a href="{% url 'customer:summary' %}" aria-label="{% trans 'Customer summary' %}" class="user-button menu-circle"><i class="fa fa-user-solid"></i></a>
				{% include 'oxyan/headers/partials/mini_basket.html' %}
			</div>

    <div class="alert-messages-header" aria-live="polite">
        {% include "oscar/partials/alert_messages.html" with messages=messages %}
    </div>