{% extends "layout.html" %}
{% load wagtailmetadata_tags wagtailcore_tags static %}

{% wagtail_site as current_site %}

{% block title %}{{self.get_meta_title}}{% if page.get_site.site_name %} - {{ page.get_site.site_name }}{% endif %}{% endblock title %}

{% block description %}{{self.get_meta_description}}{% endblock description %}

{% block extrahead %}
    {{ block.super }}
    {% meta_tags %}
{% endblock %}

{% block content_wrapper %}
	<div class="coyote-outer {% if self.monochrome %}monochrome{% endif %}" id="main_content" tabindex="-1">
	{% block content %}
	{% endblock %}
	</div>
{% endblock %}

{% block base_scss %}
	<link rel="stylesheet" type="text/x-scss" href="{% static 'carbasa/coyote_base.scss' %}">
{% endblock %}
